@@ -1,4 +1,4 @@
-use crate::Location;
+use crate::{Location, Span};
 use std::borrow::{Borrow, BorrowMut};
 use std::ops::{Deref, DerefMut};
 
@@ -47,6 +47,16 @@ impl<T, F> Loc<T, F> {
 		&mut self.1
 	}
 
+	/// Returns the value's span.
+	pub fn span(&self) -> Span {
+		self.1.span()
+	}
+
+	/// Returns a reference to the value's source file.
+	pub fn file(&self) -> &F {
+		self.1.file()
+	}
+
 	/// Maps the inner value.
 	pub fn map<U>(self, f: impl FnOnce(T) -> U) -> Loc<U, F> {
 		Loc(f(self.0), self.1)
